pub struct ValidationError {
pub code: ErrorCode,
pub message: String,
pub date: NaiveDate,
pub context: Option<String>,
pub span: Option<Span>,
pub file_id: Option<u16>,
}Expand description
A validation error.
Fields
code: ErrorCodeError code.
message: StringError message.
date: NaiveDateDate of the directive that caused the error.
context: Option<String>Additional context.
span: Option<Span>Source span (byte offsets within the file).
file_id: Option<u16>Source file ID (index into SourceMap).
Uses u16 to minimize struct size (max 65,535 files).
Implementations
Sourceimpl ValidationError
impl ValidationError
Sourcepub fn new(code: ErrorCode, message: impl Into<String>, date: NaiveDate) -> Self
pub fn new(code: ErrorCode, message: impl Into<String>, date: NaiveDate) -> Self
Create a new validation error without source location.
Sourcepub fn with_location<T>(
code: ErrorCode,
message: impl Into<String>,
date: NaiveDate,
spanned: &Spanned<T>,
) -> Self
pub fn with_location<T>( code: ErrorCode, message: impl Into<String>, date: NaiveDate, spanned: &Spanned<T>, ) -> Self
Create a new validation error with source location from a spanned directive.
Sourcepub fn with_context(self, context: impl Into<String>) -> Self
pub fn with_context(self, context: impl Into<String>) -> Self
Add context to this error.
Sourcepub const fn at_location<T>(self, spanned: &Spanned<T>) -> Self
pub const fn at_location<T>(self, spanned: &Spanned<T>) -> Self
Set the source location for this error (builder pattern).
Use this to add location info to an existing error. For creating
new errors with location, prefer Self::with_location instead.